==> regina-normal_4.96.orig.tar.gz: regina-4.96/qtui/src/packettypes/nsnappeaui.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  KDE User Interface                                                    *
 *                                                                        *
 *  Copyright (c) 1999-2014, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/* end stub */

/*! \file nsnappeaui.h
 *  \brief Provides an interface for viewing SnapPea triangulations.
 */

#ifndef __NSNAPPEAUI_H
#define __NSNAPPEAUI_H

#include "../packettabui.h"

class QToolBar;
class NSnapPeaAlgebraUI;
class NSnapPeaGluingsUI;
class NSnapPeaShapesUI;
class NTriSkeletonUI;
class PacketEditIface;
class QLabel;

namespace regina {
    class NSnapPeaTriangulation;
};

/**
 * A packet interface for viewing 3-manifold triangulations.
 */
class NSnapPeaUI : public PacketTabbedUI {
    Q_OBJECT

    private:
        /**
         * Internal components
         */
        NSnapPeaShapesUI* shapes;
        NSnapPeaGluingsUI* gluings;
        NTriSkeletonUI* skeleton;
        NSnapPeaAlgebraUI* algebra;

        PacketEditIface* editIface;

    public:
        /**
         * Constructor and destructor.
         */
        NSnapPeaUI(regina::NSnapPeaTriangulation* packet,
            PacketPane* newEnclosingPane);
        ~NSnapPeaUI();

        /**
         * PacketUI overrides.
         */
        PacketEditIface* getEditIface();
        const QLinkedList<QAction*>& getPacketTypeActions();
        QString getPacketMenuText() const;
};

/**
 * A header for the SnapPea triangulation viewer.
 */
class NSnapPeaHeaderUI : public PacketViewerTab {
    private:
        /**
         * Packet details
         */
        regina::NSnapPeaTriangulation* tri;

        /**
         * Internal components
         */
        QWidget* ui;
        QLabel* header;
        QToolBar* bar;

    public:
        /**
         * Constructor.
         */
        NSnapPeaHeaderUI(regina::NSnapPeaTriangulation* packet,
                PacketTabbedUI* useParentUI);

        /**
         * Component queries.
         */
        QToolBar* getToolBar();

        /**
         * PacketViewerTab overrides.
         */
        regina::NPacket* getPacket();
        QWidget* getInterface();
        void refresh();

        /**
         * Allow other UIs to access the summary information.
         */
        static QString summaryInfo(regina::NSnapPeaTriangulation* tri);
};

inline PacketEditIface* NSnapPeaUI::getEditIface() {
    return editIface;
}

inline QToolBar* NSnapPeaHeaderUI::getToolBar() {
    return bar;
}

#endif

==> regina-normal_5.0.orig.tar.gz: regina-5.0/qtui/src/packettypes/nsnappeaui.h <==

/**************************************************************************
 *                                                                        *
 *  Regina - A Normal Surface Theory Calculator                           *
 *  KDE User Interface                                                    *
 *                                                                        *
 *  Copyright (c) 1999-2016, Ben Burton                                   *
 *  For further details contact Ben Burton (bab@debian.org).              *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or         *
 *  modify it under the terms of the GNU General Public License as        *
 *  published by the Free Software Foundation; either version 2 of the    *
 *  License, or (at your option) any later version.                       *
 *                                                                        *
 *  As an exception, when this program is distributed through (i) the     *
 *  App Store by Apple Inc.; (ii) the Mac App Store by Apple Inc.; or     *
 *  (iii) Google Play by Google Inc., then that store may impose any      *
 *  digital rights management, device limits and/or redistribution        *
 *  restrictions that are required by its terms of service.               *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful, but   *
 *  WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *  General Public License for more details.                              *
 *                                                                        *
 *  You should have received a copy of the GNU General Public             *
 *  License along with this program; if not, write to the Free            *
 *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
 *  MA 02110-1301, USA.                                                   *
 *                                                                        *
 **************************************************************************/

/*! \file nsnappeaui.h
 *  \brief Provides an interface for viewing SnapPea triangulations.
 */

#ifndef __NSNAPPEAUI_H
#define __NSNAPPEAUI_H

#include "packet/npacketlistener.h"
#include "../packettabui.h"

class ClickableLabel;
class NSnapPeaAlgebraUI;
class NSnapPeaGluingsUI;
class NSnapPeaShapesUI;
class NTriSkeletonUI;
class PacketEditIface;
class QLabel;
class QToolBar;

namespace regina {
    class NSnapPeaTriangulation;
};

/**
 * A packet interface for viewing 3-manifold triangulations.
 */
class NSnapPeaUI : public PacketTabbedUI {
    Q_OBJECT

    private:
        /**
         * Internal components
         */
        NSnapPeaShapesUI* shapes;
        NSnapPeaGluingsUI* gluings;
        NTriSkeletonUI* skeleton;
        NSnapPeaAlgebraUI* algebra;

        PacketEditIface* editIface;

    public:
        /**
         * Constructor and destructor.
         */
        NSnapPeaUI(regina::NSnapPeaTriangulation* packet,
            PacketPane* newEnclosingPane);
        ~NSnapPeaUI();

        /**
         * PacketUI overrides.
         */
        PacketEditIface* getEditIface();
        const QLinkedList<QAction*>& getPacketTypeActions();
        QString getPacketMenuText() const;
};

/**
 * A header for the SnapPea triangulation viewer.
 */
class NSnapPeaHeaderUI : public QObject, public PacketViewerTab,
        public regina::NPacketListener {
    Q_OBJECT

    private:
        /**
         * Packet details
         */
        regina::NSnapPeaTriangulation* tri;

        /**
         * Internal components
         */
        QWidget* ui;
        QLabel* header;
        ClickableLabel* locked;
        QToolBar* bar;

    public:
        /**
         * Constructor.
         */
        NSnapPeaHeaderUI(regina::NSnapPeaTriangulation* packet,
                PacketTabbedUI* useParentUI);

        /**
         * Component queries.
         */
        QToolBar* getToolBar();

        /**
         * PacketViewerTab overrides.
         */
        regina::NPacket* getPacket();
        QWidget* getInterface();
        void refresh();

        /**
         * NPacketListener overrides.
         */
        void childWasAdded(regina::NPacket* packet, regina::NPacket* child);
        void childWasRemoved(regina::NPacket* packet, regina::NPacket* child,
            bool inParentDestructor);

        /**
         * Allow other UIs to access the summary information.
         */
        static QString summaryInfo(regina::NSnapPeaTriangulation* tri);

    public slots:
        /**
         * Explain to the user what the padlock means.
         */
        void lockedExplanation();

    protected:
        /**
         * Update the state of the padlock.
         */
        void refreshLock();

        /**
         * Allow GUI updates from a non-GUI thread.
         */
        void customEvent(QEvent* event);
};

inline PacketEditIface* NSnapPeaUI::getEditIface() {
    return editIface;
}

inline QToolBar* NSnapPeaHeaderUI::getToolBar() {
    return bar;
}

#endif
